Learn R Programming

optmatch (version 0.9-15)

model.frame.svyglm: This method quells a warning when optmatch::scores() is applied to a svyglm object. I don't expect that it to be useful in other contexts, only exporting it for ease of debugging.

Description

This method quells a warning when optmatch::scores() is applied to a svyglm object. I don't expect that it to be useful in other contexts, only exporting it for ease of debugging.

Usage

# S3 method for svyglm
model.frame(formula, ...)

Arguments