optmatch::scores()
is applied to a svyglm object. I don't expect that it to be
useful in other contexts, only exporting it for ease of debugging.This method quells a warning when optmatch::scores()
is applied to a svyglm object. I don't expect that it to be
useful in other contexts, only exporting it for ease of debugging.
# S3 method for svyglm
model.frame(formula, ...)