num_eligible_matches: Returns the number of eligible matches for the distance.
Description
This will return a list of the number of finite entries
in a distance matrix. If the distance has no subgroups,
it will be a list of length 1. If the distance has
subgroups (i.e. x is an
BlockedInfinitySparseMatrix, it will be a named
list.)Usage
num_eligible_matches(x)
Value
- A list counting the number of eligible matches in the
distance.