Rdocumentation
powered by
Learn R Programming
optmatch (version 0.8-3)
relaxinfo: Display license information about embedded code
Description
Function to display license information regarding code embedded in
optmatch
Usage
relaxinfo()
Arguments
Value
Some information about licenses of code and algorithms on which
fullmatch
depends.